@@ -2,7 +2,7 @@
   This file is part of libkldap.
 
   Copyright (c) 2003 - 2009 Tobias Koenig <tokoe@kde.org>
-  Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General  Public
@@ -23,15 +23,10 @@
 #ifndef KCMLDAP_H
 #define KCMLDAP_H
 
-#include <kcmodule.h>
-
-class QListWidget;
-class QListWidgetItem;
-class QPushButton;
-class QToolButton;
+#include <KCModule>
 
 namespace KLDAP {
-class LdapClientSearchConfig;
+class LdapConfigureWidget;
 }
 
 class KCMLdap : public KCModule
@@ -40,34 +35,13 @@ class KCMLdap : public KCModule
 
 public:
     explicit KCMLdap(QWidget *parent, const QVariantList &args);
-    ~KCMLdap();
+    ~KCMLdap() override;
 
     void load() override;
     void save() override;
-    void defaults() override;
-
-private Q_SLOTS:
-    void slotAddHost();
-    void slotEditHost();
-    void slotRemoveHost();
-    void slotSelectionChanged(QListWidgetItem *);
-    void slotItemClicked(QListWidgetItem *);
-    void slotMoveUp();
-    void slotMoveDown();
 
 private:
-    void initGUI();
-    QWidget *dialogParent();
-
-    QListWidget *mHostListView;
-
-    QPushButton *mAddButton;
-    QPushButton *mEditButton;
-    QPushButton *mRemoveButton;
-
-    QToolButton *mUpButton;
-    QToolButton *mDownButton;
-    KLDAP::LdapClientSearchConfig *mClientSearchConfig;
+    KLDAP::LdapConfigureWidget *mLdapConfigureWidget = nullptr;
 };
 
 #endif
