@@ -91,9 +91,6 @@ void TestLDAPClient::testIntevation()
     qDebug();
     mClient = new KLDAP::LdapClient(0, this);
 
-#ifdef __GNUC__
-#warning TODO!
-#endif
 #if 0
     mClient->setHost("ca.intevation.de");
     mClient->setPort("389");
