@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,11 +23,10 @@
 #include <QStringList>
 
 namespace KPIM {
-class AddresseeLineEditManager;
 class AddresseeLineEditBaloo
 {
 public:
-    explicit AddresseeLineEditBaloo(AddresseeLineEditManager *addressLineStatic);
+    AddresseeLineEditBaloo();
     ~AddresseeLineEditBaloo();
 
     int balooCompletionSource() const;
@@ -43,7 +42,6 @@ private:
     QStringList mDomainExcludeList;
 
     int mBalooCompletionSource = 0;
-    AddresseeLineEditManager *mAddressLineStatic = nullptr;
 };
 }
 
