@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -36,6 +36,8 @@ private Q_SLOTS:
     void shouldReturnChangedItems();
     void shouldNotAddDuplicateEmails();
     void shouldExcludeDomain();
+    void shouldAvoidSameEmailWithDifferentCase();
+    void shouldAvoidSameEmailWithDisplayNameOrNot();
 };
 
 #endif // BLACKLISTBALOOEMAILLISTTEST_H
