@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -79,7 +79,6 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     connect(mBlackListWarning, &BlackListBalooEmailWarning::saveChanges, this, &BlackListBalooEmailCompletionWidget::slotSaveChanges);
     mainLayout->addWidget(mBlackListWarning);
 
-
     QHBoxLayout *searchLineLayout = new QHBoxLayout;
     mainLayout->addLayout(searchLineLayout);
 
@@ -134,7 +133,6 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     mExcludeDomainLineEdit->setTrapReturnKey(true);
     mExcludeDomainLineEdit->setPlaceholderText(i18n("Separate domain with \'%1\'", QLatin1Char(',')));
 
-
     connect(mEmailList, &QListWidget::itemSelectionChanged, this, &BlackListBalooEmailCompletionWidget::slotSelectionChanged);
     slotSelectionChanged();
 }
@@ -198,7 +196,9 @@ void BlackListBalooEmailCompletionWidget::slotSearch()
         job->setSearchEmail(searchEmail);
         job->setLimit(mLimit);
         connect(job, &BlackListBalooEmailSearchJob::emailsFound, this, &BlackListBalooEmailCompletionWidget::slotEmailFound);
-        job->start();
+        if (!job->start()) {
+            qCWarning(LIBKDEPIMAKONADI_LOG) << "Impossible to start search job";
+        }
     }
 }
 
@@ -249,7 +249,11 @@ void BlackListBalooEmailCompletionWidget::slotCheckIfUpdateBlackListIsNeeded()
 void BlackListBalooEmailCompletionWidget::save()
 {
     const QString domain = mExcludeDomainLineEdit->text().remove(QLatin1Char(' '));
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList newExcludeDomain = domain.split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+    const QStringList newExcludeDomain = domain.split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
     bool needToSave = (mOriginalExcludeDomain != newExcludeDomain);
     KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kpimbalooblacklist"));
     KConfigGroup group(config, "AddressLineEdit");
