@@ -26,7 +26,7 @@
 #include <itemcreatejob.h>
 #include <kcontacts/addressee.h>
 #include <KLocalizedString>
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 #include <QPointer>
 
@@ -105,7 +105,9 @@ public:
 
             // save the new item in akonadi storage
             Akonadi::ItemCreateJob *job = new Akonadi::ItemCreateJob(item, mCollection);
-            q->connect(job, SIGNAL(result(KJob *)), SLOT(slotAddContactDone(KJob *)));
+            q->connect(job, &Akonadi::ItemCreateJob::result, q, [this](KJob *job) {
+                slotAddContactDone(job);
+            });
         } else {
             q->setError(UserDefinedError);
             q->emitResult();
@@ -138,9 +140,9 @@ public:
 
     AddContactJob *q;
     KContacts::Addressee mContact;
-    QWidget *mParentWidget;
+    QWidget *mParentWidget = nullptr;
     Akonadi::Collection mCollection;
-    bool mShowMessageBox;
+    bool mShowMessageBox = false;
 };
 
 AddContactJob::AddContactJob(const KContacts::Addressee &contact, QWidget *parentWidget, QObject *parent)
@@ -173,7 +175,9 @@ void AddContactJob::start()
     searchJob->setQuery(Akonadi::ContactSearchJob::Email, d->mContact.preferredEmail().toLower(),
                         Akonadi::ContactSearchJob::ExactMatch);
 
-    connect(searchJob, SIGNAL(result(KJob *)), SLOT(slotSearchDone(KJob *)));
+    connect(searchJob, &Akonadi::ContactSearchJob::result, this, [this](KJob *job) {
+        d->slotSearchDone(job);
+    });
 }
 
 #include "moc_addcontactjob.cpp"
