@@ -30,8 +30,7 @@
 
 namespace KPIM {
 namespace ProgressManagerAkonadi {
-KDEPIMAKONADI_EXPORT ProgressItem *createProgressItem(ProgressItem *parent, const Akonadi::AgentInstance &agent, const QString &id, const QString &label, const QString &status, bool canBeCanceled,
-                                                      ProgressItem::CryptoStatus cryptoStatus);
+KDEPIMAKONADI_EXPORT ProgressItem *createProgressItem(ProgressItem *parent, const Akonadi::AgentInstance &agent, const QString &id, const QString &label, const QString &status, bool canBeCanceled, ProgressItem::CryptoStatus cryptoStatus);
 }
 }
 #endif // PROGRESSMANAGERAKONADI_H
